@@ -9,10 +9,12 @@ from . import datasets
 from . import plots
 from . import cta
 from . import talib
+from . import pytsalib
+from . import otc
 
-__version__ = '0.0.38'
-__website__ = 'https://pypi.org/project/pybt/'
+__version__ = '0.0.4'
+__website__ = 'https://pypi.org/project/pyquantfin/'
 
 def online_help():
     import webbrowser
-    webbrowser.open('https://pypi.org/project/pybt/#description')
\ No newline at end of file
+    webbrowser.open('https://pypi.org/project/pyquantfin/#description')
\ No newline at end of file
